@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.74 2004/01/05 13:38:19 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.78 2004/01/11 02:02:19 fuyu Exp $
  */
 
 #include "config.h"
@@ -742,7 +742,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
     job = G_NEW0(WorkerJob, 1);
     job_args = G_NEW0(BBSThreadJobArgs, 1);
     buffer = ochusha_bbs_thread_get_responses_source(thread,
-				application->broker,
+				application->broker, NULL,
 				OCHUSHA_NETWORK_BROKER_CACHE_TRY_UPDATE);
 
     if (buffer == NULL)
@@ -1072,7 +1072,8 @@ ensure_popup_context(BBSThreadView *parent, OchushaBBSThread *thread,
       else
 	{
 	  BulletinBoardGUIInfo *board_info
-	    = ensure_bulletin_board_info(thread->board, application);
+	    = ensure_bulletin_board_info(ochusha_bbs_thread_get_board(thread),
+					 application);
 	  if (board_info->board_local_a_bone)
 	    {
 	      a_bone_by_name = board_info->a_bone_by_name;
@@ -1222,10 +1223,47 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
 				     event->button,
 				     gtk_get_current_event_time());
   else
-    ochusha_open_url(application, link,
-		     application->default_open_in_tab
-		     ? event->button == 1 : event->button == 2, FALSE);
+    {
+      unsigned int from;
+      unsigned int to;
+      if (ochusha_bbs_thread_check_url(thread, link, &from, &to))
+	{
+	  /* URL */
+	  if (from == 0 && to > 0)
+	    from = to;
+	  if (from > 0)
+	    {
+	      BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+	      GtkWidget *root_view;
+	      PanedNotebook *paned_notebook
+		= PANED_NOTEBOOK(application->contents_window);
+	      paned_notebook
+		= PANED_NOTEBOOK(paned_notebook_get_item_view(paned_notebook,
+							      thread->board));
+	      if (paned_notebook == NULL)
+		return TRUE;
 
+	      root_view = paned_notebook_get_item_view(paned_notebook, thread);
+	      if (root_view == NULL)
+		return TRUE;
+
+	      root_view = gtk_bin_get_child(GTK_BIN(root_view));
+
+	      if (info->offsets != NULL && info->offsets_length > from
+		  && info->offsets[from] > 0)
+		{
+		  /*  */
+		  save_thread_view_position(root_view, thread);
+		  bbs_thread_view_scroll_to_offset(BBS_THREAD_VIEW(root_view),
+						   info->offsets[from]);
+		}
+	    }
+	}
+      else
+	ochusha_open_url(application, link,
+			 application->default_open_in_tab
+			 ? event->button == 1 : event->button == 2, FALSE);
+    }
   return TRUE;
 }
 
@@ -1271,7 +1309,8 @@ show_mailto(OchushaApplication *application, OchushaBBSThread *thread)
     return (thread_info->show_mailto_mode
 	    == THREAD_VIEW_MAILTO_MODE_SHOW);
 
-  board_info = ensure_bulletin_board_info(thread->board, application);
+  board_info = ensure_bulletin_board_info(ochusha_bbs_thread_get_board(thread),
+					  application);
   if (board_info->show_mailto_mode != THREAD_VIEW_MAILTO_MODE_DEFAULT)
     return (board_info->show_mailto_mode
 	    == THREAD_VIEW_MAILTO_MODE_SHOW);
@@ -1390,12 +1429,15 @@ bookmark_clicked_cb(GtkWidget *widget, BBSThreadView *view)
 
   info = ensure_bbs_thread_info(thread);
 
-  if (info->bookmark_response_number == thread->number_of_responses_read)
+  if (info->bookmark_response_number
+      == ochusha_bbs_thread_get_number_of_responses_read(thread))
     return;
 
   MAIN_THREAD_EVENT_CALLBACK();
 
-  insert_bookmark(view, thread, thread->number_of_responses_read, application);
+  insert_bookmark(view, thread,
+		  ochusha_bbs_thread_get_number_of_responses_read(thread),
+		  application);
 
   ENTER_MAIN_EVENT_LOOP();
 }
@@ -1543,7 +1585,8 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       thread,					/* thread */
       info,					/* info */
       application,				/* application */
-      thread->number_of_responses_read,		/* last_read_number */
+      ochusha_bbs_thread_get_number_of_responses_read(thread),
+      						/* last_read_number */
       job_args->start,				/* last_rendered_response */
       job_args->start > 0,			/* title_shown */
 
@@ -1600,7 +1643,8 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   else
     {
       BulletinBoardGUIInfo *board_info
-	= ensure_bulletin_board_info(thread->board, application);
+	= ensure_bulletin_board_info(ochusha_bbs_thread_get_board(thread),
+				     application);
       if (board_info->board_local_a_bone)
 	{
 	  a_bone_by_name = board_info->a_bone_by_name;
@@ -1714,7 +1758,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
     {
       snprintf(default_text_buffer, DEFAULT_BUFFER_SIZE,
 	       _("Updating thread %s@%s board"),
-	       thread->title, thread->board->name);
+	       thread->title, ochusha_bbs_thread_get_board(thread)->name);
 
       OCHU_THREADS_ENTER();
 
@@ -1740,7 +1784,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
     {
       snprintf(default_text_buffer, DEFAULT_BUFFER_SIZE,
 	       _("Getting thread %s@%s board"),
-	       thread->title, thread->board->name);
+	       thread->title, ochusha_bbs_thread_get_board(thread)->name);
 
       OCHU_THREADS_ENTER();
 
@@ -1821,7 +1865,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 
 
 static gboolean
-start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
+start_thread_rendering(OchushaBBSThread *real_thread, const gchar *title,
 		       gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
@@ -1872,11 +1916,12 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 #define LARGE_COLON		"\357\274\232"
 
 static gboolean
-render_response(OchushaBBSThread *thread, int number,
+render_response(OchushaBBSThread *real_thread, int number,
 		const OchushaBBSResponse *response,
 		gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
+  OchushaBBSThread *thread = context->thread;
   BBSThreadView *view = context->view;
   BBSThreadGUIInfo *info = context->info;
   char buffer[18];
@@ -1924,8 +1969,8 @@ render_response(OchushaBBSThread *thread, int number,
       save_initial_thread_view_position(view, info, mark);
     }
 
-  if (thread->number_of_responses_read < number)
-    thread->number_of_responses_read = number;
+  if (ochusha_bbs_thread_get_number_of_responses_read(thread) < number)
+    ochusha_bbs_thread_set_number_of_responses_read(thread, number);
 
   info->num_shown = number;
   update_threadlist_entry(context->application, thread);
@@ -2096,10 +2141,11 @@ render_response(OchushaBBSThread *thread, int number,
 
 
 static gboolean
-render_broken_response(OchushaBBSThread *thread, int number,
+render_broken_response(OchushaBBSThread *real_thread, int number,
 		       gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
+  OchushaBBSThread *thread = context->thread;
   BBSThreadView *view = context->view;
   BBSThreadGUIInfo *info = context->info;
   char buffer[13];
@@ -2132,8 +2178,8 @@ render_broken_response(OchushaBBSThread *thread, int number,
       save_initial_thread_view_position(view, info, mark);
     }
   
-  if (thread->number_of_responses_read < number)
-    thread->number_of_responses_read = number;
+  if (ochusha_bbs_thread_get_number_of_responses_read(thread) < number)
+    ochusha_bbs_thread_set_number_of_responses_read(thread, number);
 
   info->num_shown = number;
   update_threadlist_entry(context->application, thread);
@@ -2177,10 +2223,11 @@ render_broken_response(OchushaBBSThread *thread, int number,
 
 
 static gboolean
-end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
+end_thread_rendering(OchushaBBSThread *real_thread, gboolean finished,
 		     gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
+  OchushaBBSThread *thread = context->thread;
   BBSThreadView *view = context->view;
   BBSThreadGUIInfo *info = context->info;
 
@@ -2219,7 +2266,7 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
        */
       snprintf(message, DEFAULT_BUFFER_SIZE,
 	       _("A Bone occurs in thread %s@%s board"),
-	       thread->title, thread->board->name);
+	       thread->title, ochusha_bbs_thread_get_board(thread)->name);
 
       OCHU_THREADS_ENTER();
 
@@ -2231,7 +2278,7 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
 
       OCHU_THREADS_LEAVE();
 
-      thread->number_of_responses_read = 1;
+      ochusha_bbs_thread_set_number_of_responses_read(thread, 1);
       /* 0ˤȡɤ߹ߤߤˡå夬ĤäƤΤ̤
        * ˤʤ륿ߥ󥰤Τǡ
        */
@@ -2596,11 +2643,12 @@ prepare_buffer_for_popup(OchushaApplication *application,
   fprintf(stderr, "prepare_buffer_for_popup(): from=%d, to=%d\n", from, to);
 #endif
 
-  if ((from == 0 && to == 0) || from > thread->number_of_responses_read)
+  if ((from == 0 && to == 0)
+      || from > ochusha_bbs_thread_get_number_of_responses_read(thread))
     return FALSE;
 
-  if (to > thread->number_of_responses_read)
-    to = thread->number_of_responses_read;
+  if (to > ochusha_bbs_thread_get_number_of_responses_read(thread))
+    to = ochusha_bbs_thread_get_number_of_responses_read(thread);
 
   if (to > 0 && from > to)
     {
@@ -2624,7 +2672,7 @@ prepare_buffer_for_popup(OchushaApplication *application,
     }
 
   *buffer = ochusha_bbs_thread_get_responses_source(thread,
-					application->broker,
+					application->broker, NULL,
 					OCHUSHA_NETWORK_BROKER_CACHE_ONLY);
   info->response_source_buffer = *buffer;
 
@@ -3189,7 +3237,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
     job_args = G_NEW0(BBSThreadJobArgs, 1);
     old_buffer = info->response_source_buffer;
     buffer = ochusha_bbs_thread_get_responses_source(thread,
-				application->broker,
+				application->broker, old_buffer,
 				OCHUSHA_NETWORK_BROKER_CACHE_TRY_UPDATE);
 
     if (buffer == NULL)
@@ -3205,6 +3253,9 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 	return;
       }
 
+    if (buffer == old_buffer)
+      old_buffer = NULL;
+
     setup_for_tab_label_animation(buffer, tab_label);
 
     info->response_source_buffer = buffer;
@@ -3214,7 +3265,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
     job_args->thread = thread;
     job_args->view = view;
     job_args->buffer = buffer;
-    job_args->start = thread->number_of_responses_read;
+    job_args->start = ochusha_bbs_thread_get_number_of_responses_read(thread);
     job_args->number_of_responses = -1;
     job_args->refresh = TRUE;
     job_args->tab_label = tab_label;
@@ -3255,6 +3306,19 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 }
 
 
+void
+save_thread_view_position(GtkWidget *widget, OchushaBBSThread *thread)
+{
+  BBSThreadView *view = BBS_THREAD_VIEW(widget);
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+  info->backward_history
+    = g_slist_prepend(info->backward_history,
+		      (gpointer)bbs_thread_view_get_visible_offset(view));
+  g_slist_free(info->forward_history);
+  info->forward_history = NULL;
+}
+
+
 void
 go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
@@ -3263,6 +3327,7 @@ go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread)
   g_return_if_fail(widget != NULL);
 
   view = BBS_THREAD_VIEW(widget);
+  save_thread_view_position(widget, thread);
   bbs_thread_view_scroll_to_start(view);
 }
 
@@ -3275,6 +3340,7 @@ go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread)
   g_return_if_fail(widget != NULL);
 
   view = BBS_THREAD_VIEW(widget);
+  save_thread_view_position(widget, thread);
   bbs_thread_view_scroll_to_end(view);
 }
 
@@ -3289,5 +3355,8 @@ jump_to_bookmark(GtkWidget *widget, OchushaBBSThread *thread)
   view = BBS_THREAD_VIEW(widget);
   info = ensure_bbs_thread_info(thread);
   if (info->last_read != NULL)
-    bbs_thread_view_scroll_to_mark(view, info->last_read);
+    {
+      save_thread_view_position(widget, thread);
+      bbs_thread_view_scroll_to_mark(view, info->last_read);
+    }
 }
