@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: board_properties.c,v 1.11 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: board_properties.c,v 1.13 2004/01/11 23:18:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -36,11 +36,14 @@
 #include "boardlist_ui.h"
 #include "regex_utils.h"
 #include "threadlist_filter.h"
+#include "virtual_board.h"
 
 #include <gtk/gtk.h>
 
 #include <pthread.h>
+
 #include <stdlib.h>
+#include <string.h>
 
 
 typedef struct _DialogStates
@@ -49,6 +52,9 @@ typedef struct _DialogStates
   OchushaBulletinBoard *board;
   BulletinBoardGUIInfo *info;
 
+  GtkEntry *board_name_entry;
+  GtkEntry *board_url_entry;
+
   GtkToggleButton *use_ochusha_default_button;
   GtkToggleButton *show_mailto_button;
   GtkToggleButton *hide_mailto_button;
@@ -208,67 +214,72 @@ open_board_properties(OchushaApplication *application,
 			       info->enable_filter);
 
 
-  frame = build_thread_view_setting_frame(application, board, states);
-  gtk_widget_show(frame);
-
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame,
-			   gtk_label_new(_("Default Setting of Thread Views on This Board")));
-
-  g_signal_connect(G_OBJECT(states->board_local_a_bone_button), "toggled",
-		   G_CALLBACK(board_local_a_bone_toggled_cb), states);
-
-  switch (info->show_mailto_mode)
+  if (!IS_VIRTUAL_BOARD(board))
     {
-    case THREAD_VIEW_MAILTO_MODE_DEFAULT:
-      gtk_toggle_button_set_active(states->use_ochusha_default_button, TRUE);
-      break;
+      frame = build_thread_view_setting_frame(application, board, states);
+      gtk_widget_show(frame);
 
-    case THREAD_VIEW_MAILTO_MODE_SHOW:
-      gtk_toggle_button_set_active(states->show_mailto_button, TRUE);
-      break;
+      gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame,
+			       gtk_label_new(_("Default Setting of Thread Views on This Board")));
 
-    case THREAD_VIEW_MAILTO_MODE_HIDE:
-      gtk_toggle_button_set_active(states->hide_mailto_button, TRUE);
-      break;
+      g_signal_connect(G_OBJECT(states->board_local_a_bone_button), "toggled",
+		       G_CALLBACK(board_local_a_bone_toggled_cb), states);
+
+      switch (info->show_mailto_mode)
+	{
+	case THREAD_VIEW_MAILTO_MODE_DEFAULT:
+	  gtk_toggle_button_set_active(states->use_ochusha_default_button,
+				       TRUE);
+	  break;
+
+	case THREAD_VIEW_MAILTO_MODE_SHOW:
+	  gtk_toggle_button_set_active(states->show_mailto_button, TRUE);
+	  break;
+
+	case THREAD_VIEW_MAILTO_MODE_HIDE:
+	  gtk_toggle_button_set_active(states->hide_mailto_button, TRUE);
+	  break;
+	}
+
+      if (info->board_local_a_bone)
+	{
+	  gtk_toggle_button_set_active(states->a_bone_by_name_button,
+				       info->a_bone_by_name);
+	  regex_editor_set_regex_text(states->a_bone_by_name_pattern,
+				      info->a_bone_by_name_pattern);
+	  gtk_toggle_button_set_active(states->a_bone_by_id_button,
+				       info->a_bone_by_id);
+	  regex_editor_set_regex_text(states->a_bone_by_id_pattern,
+				      info->a_bone_by_id_pattern);
+	  gtk_toggle_button_set_active(states->a_bone_by_content_button,
+				       info->a_bone_by_content);
+	  regex_editor_set_regex_text(states->a_bone_by_content_pattern,
+				      info->a_bone_by_content_pattern);
+	}
+      else
+	{
+	  gtk_toggle_button_set_active(states->a_bone_by_name_button,
+				       application->a_bone_by_name);
+	  regex_editor_set_regex_text(states->a_bone_by_name_pattern,
+				      application->a_bone_by_name_pattern);
+	  gtk_toggle_button_set_active(states->a_bone_by_id_button,
+				       application->a_bone_by_id);
+	  regex_editor_set_regex_text(states->a_bone_by_id_pattern,
+				      application->a_bone_by_id_pattern);
+	  gtk_toggle_button_set_active(states->a_bone_by_content_button,
+				       application->a_bone_by_content);
+	  regex_editor_set_regex_text(states->a_bone_by_content_pattern,
+				      application->a_bone_by_content_pattern);
+	}
+
+      gtk_toggle_button_set_active(states->board_local_a_bone_button,
+				   info->board_local_a_bone);
+      /* 礤ȥܤä */
+      board_local_a_bone_toggled_cb(states->board_local_a_bone_button, states);
     }
 
-  if (info->board_local_a_bone)
-    {
-      gtk_toggle_button_set_active(states->a_bone_by_name_button,
-				   info->a_bone_by_name);
-      regex_editor_set_regex_text(states->a_bone_by_name_pattern,
-				  info->a_bone_by_name_pattern);
-      gtk_toggle_button_set_active(states->a_bone_by_id_button,
-				   info->a_bone_by_id);
-      regex_editor_set_regex_text(states->a_bone_by_id_pattern,
-				  info->a_bone_by_id_pattern);
-      gtk_toggle_button_set_active(states->a_bone_by_content_button,
-				   info->a_bone_by_content);
-      regex_editor_set_regex_text(states->a_bone_by_content_pattern,
-				  info->a_bone_by_content_pattern);
-    }
-  else
-    {
-      gtk_toggle_button_set_active(states->a_bone_by_name_button,
-				   application->a_bone_by_name);
-      regex_editor_set_regex_text(states->a_bone_by_name_pattern,
-				  application->a_bone_by_name_pattern);
-      gtk_toggle_button_set_active(states->a_bone_by_id_button,
-				   application->a_bone_by_id);
-      regex_editor_set_regex_text(states->a_bone_by_id_pattern,
-				  application->a_bone_by_id_pattern);
-      gtk_toggle_button_set_active(states->a_bone_by_content_button,
-				   application->a_bone_by_content);
-      regex_editor_set_regex_text(states->a_bone_by_content_pattern,
-				  application->a_bone_by_content_pattern);
-    }
-
-  gtk_toggle_button_set_active(states->board_local_a_bone_button,
-			       info->board_local_a_bone);
-  /* 礤ȥܤä */
-  board_local_a_bone_toggled_cb(states->board_local_a_bone_button, states);
-
   gtk_widget_show_all(dialog);
+  gtk_widget_grab_focus(GTK_DIALOG(dialog)->action_area);
 }
 
 
@@ -318,55 +329,90 @@ apply_current_states(GtkWidget *dialog, DialogStates *states)
   BulletinBoardGUIInfo *info = states->info;
   const ThreadlistFilter *filter;
 
+  if (states->board_name_entry != NULL
+      && strcmp(states->board->name,
+		gtk_entry_get_text(states->board_name_entry)) != 0)
+    {
+      ochusha_bulletin_board_set_name(states->board,
+				      gtk_entry_get_text(states->board_name_entry));
+      redraw_boardlist(states->application);
+    }
+
+  if (states->board_url_entry != NULL)
+    {
+      if (IS_VIRTUAL_BOARD(states->board))
+	{
+	  if (strcmp(states->board->id,
+		     gtk_entry_get_text(states->board_url_entry)) != 0)
+	    {
+	      char url_buffer[PATH_MAX];
+	      snprintf(url_buffer, PATH_MAX, "http:///%s",
+		       gtk_entry_get_text(states->board_url_entry));
+	      ochusha_bulletin_board_set_base_url(states->board,
+						  url_buffer);
+	    }
+	}
+      else
+	{
+	  if (strcmp(states->board->base_url,
+		     gtk_entry_get_text(states->board_url_entry)) != 0)
+	    ochusha_bulletin_board_set_base_url(states->board,
+						gtk_entry_get_text(states->board_url_entry));
+	}
+    }
+
   filter = threadlist_filter_setting_get_filter(states->setting);
   info->enable_filter
     = gtk_toggle_button_get_active(states->enable_filter_button);
 
-  if (gtk_toggle_button_get_active(states->show_mailto_button))
+  if (!IS_VIRTUAL_BOARD(states->board))
     {
-      info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_SHOW;
-    }
-  else if (gtk_toggle_button_get_active(states->hide_mailto_button))
-    {
-      info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_HIDE;
-    }
-  else
-    {
-      info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_DEFAULT;
-    }
+      if (gtk_toggle_button_get_active(states->show_mailto_button))
+	{
+	  info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_SHOW;
+	}
+      else if (gtk_toggle_button_get_active(states->hide_mailto_button))
+	{
+	  info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_HIDE;
+	}
+      else
+	{
+	  info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_DEFAULT;
+	}
 
-  info->board_local_a_bone
-    = gtk_toggle_button_get_active(states->board_local_a_bone_button);
+      info->board_local_a_bone
+	= gtk_toggle_button_get_active(states->board_local_a_bone_button);
 
-  if (info->a_bone_by_name_pattern != NULL)
-    G_FREE(info->a_bone_by_name_pattern);
+      if (info->a_bone_by_name_pattern != NULL)
+	G_FREE(info->a_bone_by_name_pattern);
 
-  if (info->a_bone_by_id_pattern != NULL)
-    G_FREE(info->a_bone_by_id_pattern);
+      if (info->a_bone_by_id_pattern != NULL)
+	G_FREE(info->a_bone_by_id_pattern);
 
-  if (info->a_bone_by_content_pattern != NULL)
-    G_FREE(info->a_bone_by_content_pattern);
+      if (info->a_bone_by_content_pattern != NULL)
+	G_FREE(info->a_bone_by_content_pattern);
 
-  if (info->board_local_a_bone)
-    {
-      info->a_bone_by_name
-	= gtk_toggle_button_get_active(states->a_bone_by_name_button);
-      info->a_bone_by_name_pattern
-	= regex_editor_get_regex_text(states->a_bone_by_name_pattern);
-      info->a_bone_by_id
-	= gtk_toggle_button_get_active(states->a_bone_by_id_button);
-      info->a_bone_by_id_pattern
-	= regex_editor_get_regex_text(states->a_bone_by_id_pattern);
-      info->a_bone_by_content
-	= gtk_toggle_button_get_active(states->a_bone_by_content_button);
-      info->a_bone_by_content_pattern
-	= regex_editor_get_regex_text(states->a_bone_by_content_pattern);
-    }
-  else
-    {
-      info->a_bone_by_name_pattern = NULL;
-      info->a_bone_by_id_pattern = NULL;
-      info->a_bone_by_content_pattern = NULL;
+      if (info->board_local_a_bone)
+	{
+	  info->a_bone_by_name
+	    = gtk_toggle_button_get_active(states->a_bone_by_name_button);
+	  info->a_bone_by_name_pattern
+	    = regex_editor_get_regex_text(states->a_bone_by_name_pattern);
+	  info->a_bone_by_id
+	    = gtk_toggle_button_get_active(states->a_bone_by_id_button);
+	  info->a_bone_by_id_pattern
+	    = regex_editor_get_regex_text(states->a_bone_by_id_pattern);
+	  info->a_bone_by_content
+	    = gtk_toggle_button_get_active(states->a_bone_by_content_button);
+	  info->a_bone_by_content_pattern
+	    = regex_editor_get_regex_text(states->a_bone_by_content_pattern);
+	}
+      else
+	{
+	  info->a_bone_by_name_pattern = NULL;
+	  info->a_bone_by_id_pattern = NULL;
+	  info->a_bone_by_content_pattern = NULL;
+	}
     }
 
   if (gtk_toggle_button_get_active(states->use_as_default_button))
@@ -452,36 +498,80 @@ build_board_info_frame(OchushaApplication *application,
   GtkWidget *tmp_widget;
   GtkWidget *board_frame = gtk_frame_new(NULL);
 
-#if 0	/* themeˤޤ٤ */
-  gtk_frame_set_shadow_type(GTK_FRAME(board_frame), GTK_SHADOW_ETCHED_OUT);
-#endif
   gtk_widget_show(board_frame);
 
   table = gtk_table_new(2, 5, FALSE);
   gtk_widget_show(table);
   gtk_container_add(GTK_CONTAINER(board_frame), table);
 
-  tmp_widget = gtk_label_new(_("Board's Name"));
-  gtk_widget_show(tmp_widget);
-  gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 0, 1);
+  if (!IS_VIRTUAL_BOARD(board))
+    {
+      tmp_widget = gtk_label_new(_("Board's Name"));
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 0, 1);
 
-  tmp_widget = gtk_entry_new();
-  gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->name);
-  gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE);
-  GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
-  gtk_widget_show(tmp_widget);
-  gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 0, 1);
+      tmp_widget = gtk_entry_new();
+      gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->name);
+      gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE);
+      GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 0, 1);
+      states->board_name_entry = NULL;
 
-  tmp_widget = gtk_label_new(_("Board's URL"));
-  gtk_widget_show(tmp_widget);
-  gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 1, 2);
+      tmp_widget = gtk_label_new(_("Board's URL"));
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 1, 2);
 
-  tmp_widget = gtk_entry_new();
-  gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->base_url);
-  gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE);
-  GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
-  gtk_widget_show(tmp_widget);
-  gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 1, 2);
+      tmp_widget = gtk_entry_new();
+      gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->base_url);
+#if 0
+      gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE);
+      GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
+#else
+      gtk_editable_select_region(GTK_EDITABLE(tmp_widget), 0, 0);
+      gtk_entry_set_activates_default(GTK_ENTRY(tmp_widget), FALSE);
+#endif
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 1, 2);
+      states->board_url_entry = GTK_ENTRY(tmp_widget);
+    }
+  else
+    {
+      tmp_widget = gtk_label_new(_("Virtual Board's Name"));
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 0, 1);
+
+      tmp_widget = gtk_entry_new();
+      gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->name);
+      /* gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE); */
+      /* GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS); */
+      gtk_editable_select_region(GTK_EDITABLE(tmp_widget), 0, 0);
+      gtk_entry_set_activates_default(GTK_ENTRY(tmp_widget), FALSE);
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 0, 1);
+      states->board_name_entry = GTK_ENTRY(tmp_widget);
+
+      tmp_widget = gtk_label_new(_("Virtual Board's ID"));
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 0, 1, 1, 2);
+
+      tmp_widget = gtk_entry_new();
+      gtk_entry_set_text(GTK_ENTRY(tmp_widget), board->id);
+      if (strcmp(board->id, "favorites") == 0)
+	{
+	  gtk_editable_set_editable(GTK_EDITABLE(tmp_widget), FALSE);
+	  GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
+	}
+      else
+	{
+	  gtk_editable_select_region(GTK_EDITABLE(tmp_widget), 0, 0);
+	  gtk_entry_set_activates_default(GTK_ENTRY(tmp_widget), FALSE);
+	  states->board_url_entry = GTK_ENTRY(tmp_widget);
+	}
+
+      gtk_widget_show(tmp_widget);
+      gtk_table_attach_defaults(GTK_TABLE(table), tmp_widget, 1, 5, 1, 2);
+    }
 
   return board_frame;
 }
