@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.68 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.69 2004/01/11 22:34:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -81,12 +81,13 @@ static void toggle_hide_category_cb(BoardlistView *view,
 static void toggle_hide_board_cb(BoardlistView *view,
 				 OchushaBulletinBoard *board,
 				 OchushaApplication *application);
-static void kill_category_cb(BoardlistView *view,
-			     OchushaBoardCategory *category,
-			     OchushaApplication *application);
-static void kill_board_cb(BoardlistView *view, OchushaBoardCategory *category,
-			  OchushaBulletinBoard *board,
-			  OchushaApplication *application);
+static gboolean kill_category_cb(BoardlistView *view,
+				 OchushaBoardCategory *category,
+				 OchushaApplication *application);
+static gboolean kill_board_cb(BoardlistView *view,
+			      OchushaBoardCategory *category,
+			      OchushaBulletinBoard *board,
+			      OchushaApplication *application);
 static void copy_board_url_cb(BoardlistView *view, OchushaBulletinBoard *board,
 			      OchushaApplication *application);
 static void uri_dropped_cb(BoardlistView *view, OchushaBoardCategory *category,
@@ -1478,20 +1479,35 @@ toggle_hide_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
 }
 
 
-static void
+static gboolean
 kill_category_cb(BoardlistView *view, OchushaBoardCategory *category,
 		 OchushaApplication *application)
 {
-  category->killed = TRUE;
+  BoardCategoryGUIInfo *info = ensure_board_category_info(category);
+  if (info->category_type != CATEGORY_TYPE_OCHUSHA_MY_FOLDER)
+    {
+      category->killed = TRUE;
+      return TRUE;
+    }
+  return FALSE;
 }
 
 
-static void
+static gboolean
 kill_board_cb(BoardlistView *view, OchushaBoardCategory *category,
 	      OchushaBulletinBoard *board, OchushaApplication *application)
 {
   if (category != NULL)
-    ochusha_board_category_remove_board(category, board);
+    {
+      if (IS_VIRTUAL_BOARD(board))
+	{
+	  BoardCategoryGUIInfo *info = ensure_board_category_info(category);
+	  if (info->category_type == CATEGORY_TYPE_OCHUSHA_MY_FOLDER)
+	    return FALSE;
+	}
+      ochusha_board_category_remove_board(category, board);
+    }
+  return TRUE;
 }
 
 
@@ -1712,17 +1728,6 @@ setup_boardlist(OchushaApplication *application)
 
   gtk_widget_show_all(application->boardlist_view);
   gtk_widget_show_all(application->contents_window);
-
-#if 0
-  if (IS_VIRTUAL_BOARD(application->favorites)
-      && application->favorites->thread_list == NULL)
-    {
-      ochusha_bulletin_board_read_threadlist_xml(application->favorites,
-						 &application->config,
-						 application->session_subdir,
-						 FALSE);
-    }
-#endif
 }
 
 
