@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.h,v 1.10 2003/12/23 15:37:32 fuyu Exp $
+ * $Id: boardlist_ui.h,v 1.12 2004/01/09 22:14:00 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_UI_H_
@@ -42,8 +42,25 @@
 extern "C" {
 #endif
 
+
+enum
+{
+  CATEGORY_TYPE_BBS_MENU_CATEGORY = 0,
+  CATEGORY_TYPE_OCHUSHA_MY_FOLDER,
+  CATEGORY_TYPE_USER_CATEGORY
+};
+
+
+typedef struct _BoardCategoryGUIInfo
+{
+  gboolean expanded;
+  int category_type;
+} BoardCategoryGUIInfo;
+
+
 void prepare_boardlist_ui_initialization(OchushaApplication *application);
 void initialize_boardlist(OchushaApplication *application);
+BoardCategoryGUIInfo *ensure_board_category_info(OchushaBoardCategory *category);
 void refresh_boardlist(OchushaApplication *application);
 void redraw_boardlist(OchushaApplication *appliction);
 void finalize_boardlist(OchushaApplication *application);
