@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.27 2004/01/10 23:37:50 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.28 2004/01/11 22:34:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -435,8 +435,8 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(BoardlistViewClass, kill_category),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__OBJECT,
-		 G_TYPE_NONE, 1,
+		 ochusha_marshal_BOOLEAN__OBJECT,
+		 G_TYPE_BOOLEAN, 1,
 		 OCHUSHA_TYPE_BOARD_CATEGORY);
   boardlist_view_signals[KILL_BOARD_SIGNAL] =
     g_signal_new("kill_board",
@@ -444,8 +444,8 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(BoardlistViewClass, kill_board),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__OBJECT_OBJECT,
-		 G_TYPE_NONE, 2,
+		 ochusha_marshal_BOOLEAN__OBJECT_OBJECT,
+		 G_TYPE_BOOLEAN, 2,
 		 OCHUSHA_TYPE_BOARD_CATEGORY,
 		 OCHUSHA_TYPE_BULLETIN_BOARD);
   boardlist_view_signals[COPY_BOARD_URL_SIGNAL] =
@@ -1105,22 +1105,26 @@ do_on_selection_helper(gpointer list_data, gpointer user_data)
     case POPUP_MENU_KILL_SELECTION:
       if (OCHUSHA_IS_BOARD_CATEGORY(data))
 	{
+	  gboolean result = FALSE;
 	  OchushaBoardCategory *category = OCHUSHA_BOARD_CATEGORY(data);
 	  g_signal_emit(G_OBJECT(args->view),
 			boardlist_view_signals[KILL_CATEGORY_SIGNAL],
 			0,
-			category);
+			category,
+			&result);
 	  gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			     BOARDLIST_ROW_STATE,
 			     encode_row_state(category->hidden,
 					      category->killed),
 			     -1);
-	  args->hidden_categories
-	    = g_slist_append(args->hidden_categories,
-			     gtk_tree_row_reference_new(model, path));
+	  if (result)
+	    args->hidden_categories
+	      = g_slist_append(args->hidden_categories,
+			       gtk_tree_row_reference_new(model, path));
 	}
       else if (OCHUSHA_IS_BULLETIN_BOARD(data))
 	{
+	  gboolean result = FALSE;
 	  GtkTreePath *category_path = gtk_tree_path_copy(path);
 	  OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(data);
 	  OchushaBoardCategory *category = NULL;
@@ -1139,14 +1143,16 @@ do_on_selection_helper(gpointer list_data, gpointer user_data)
 			boardlist_view_signals[KILL_BOARD_SIGNAL],
 			0,
 			category,
-			board);
+			board,
+			&result);
 	  gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			     BOARDLIST_ROW_STATE,
 			     encode_row_state(board->hidden, board->killed),
 			     -1);
-	  args->hidden_boards
-	    = g_slist_append(args->hidden_boards,
-			     gtk_tree_row_reference_new(model, path));
+	  if (result)
+	    args->hidden_boards
+	      = g_slist_append(args->hidden_boards,
+			       gtk_tree_row_reference_new(model, path));
 	  gtk_tree_path_free(category_path);
 	}
       break;
