@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.h,v 1.15 2004/01/10 23:37:50 fuyu Exp $
+ * $Id: boardlist_view.h,v 1.16 2004/01/11 22:34:41 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -82,9 +82,10 @@ struct _BoardlistViewClass
 			       OchushaBoardCategory *category);
   void (*toggle_hide_board)(BoardlistView *view,
 			    OchushaBulletinBoard *board);
-  void (*kill_category)(BoardlistView *view, OchushaBoardCategory *category);
-  void (*kill_board)(BoardlistView *view, OchushaBoardCategory *category,
-		     OchushaBulletinBoard *board);
+  gboolean (*kill_category)(BoardlistView *view,
+			    OchushaBoardCategory *category);
+  gboolean (*kill_board)(BoardlistView *view, OchushaBoardCategory *category,
+			 OchushaBulletinBoard *board);
   void (*copy_board_url)(BoardlistView *view, OchushaBulletinBoard *board);
 
   gboolean (*advance_view)(BoardlistView *view);
