@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.111 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.112 2004/01/11 22:33:04 fuyu Exp $
  */
 
 #include "config.h"
@@ -735,19 +735,30 @@ customize_threadlist_view_contents(OchushaApplication *application,
 static void
 open_thread_view_cb(GtkWidget *selector, OchushaBBSThread *thread,
 		    gboolean in_tab, gboolean with_browser,
-		    PanedNotebook *paned_notebook)
+		    gboolean fake_relation, PanedNotebook *paned_notebook)
 {
   OchushaApplication *application = g_object_get_qdata(G_OBJECT(selector),
 						       application_id);
-  if (!with_browser)
+  if (!with_browser && !with_browser)
     paned_notebook_open_item_view(paned_notebook, thread, in_tab,
 				  application->select_tab_when_opened);
   else
     {
       if (application != NULL)
-	ochusha_open_url(application,
-			 ochusha_bbs_thread_get_url_to_post_response(thread),
-			 in_tab, with_browser);
+	{
+	  const char *url
+	    = ochusha_bbs_thread_get_url_to_post_response(thread);
+	  if (!fake_relation)
+	    ochusha_open_url(application, url, in_tab, with_browser);
+	  else if (ochusha_bulletin_board_get_bbs_type(ochusha_bbs_thread_get_board(thread)) == OCHUSHA_BBS_TYPE_2CH)
+	    {
+	      char url_buffer[PATH_MAX];
+	      snprintf(url_buffer, PATH_MAX,
+		       "http://info.2ch.net/test/tb.cgi?__mode=list&tb_id=%s",
+		       ochusha_bbs_thread_get_url(thread));
+	      ochusha_open_url(application, url_buffer, in_tab, TRUE);
+	    }
+	}
 #if 0	/* Թͽ */
       else
 	fprintf(stderr, "open_thread_view_cb: %s\n",
