@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.24 2003/12/30 21:53:28 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.26 2004/01/11 02:02:19 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -144,10 +144,14 @@ void update_threadlist_entry_style(OchushaApplication *application,
 
 void refresh_current_thread(OchushaApplication *application);
 void start_thread_search(OchushaApplication *application);
+
 void jump_to_bookmark_of_current_thread(OchushaApplication *application);
 void go_to_the_last_response_of_current_thread(OchushaApplication *application);
 void go_to_the_first_response_of_current_thread(OchushaApplication *application);
 
+void bookmark_thread(OchushaBulletinBoard *board, OchushaBBSThread *thread,
+		     OchushaApplication *application);
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
