@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.76 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.77 2004/01/11 22:35:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -261,6 +261,36 @@ ochusha_init_application(OchushaApplication *application)
       MAIN_MENU_REFRESH_BOARDLIST,
       NULL
     },
+#if 0	/* 褺ȥ */
+    {
+      _("/Board/-------"),
+      NULL,
+      NULL,
+      0,
+      (char *)"<Separator>"
+    },
+    {
+      _("/Board/_Create New Category"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_CREATE_NEW_CATEGORY,
+      NULL,
+    },
+    {
+      _("/Board/_Add Board"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_ADD_BOARD,
+      NULL,
+    },
+    {
+      _("/Board/Create New _Virtual Board"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_CREATE_NEW_VIRTUAL_BOARD,
+      NULL,
+    },
+#endif
     {
       _("/Board/-------"),
       NULL,
@@ -639,7 +669,7 @@ ochusha_clipboard_set_text(OchushaApplication *application, const gchar *text)
 
 #define COMMAND_LINE_BUFFER_SIZE	4096
 void
-ochusha_open_url(OchushaApplication *application, const gchar *url,
+ochusha_open_url(OchushaApplication *application, const char *url,
 		 gboolean in_tab, gboolean use_web_browser)
 {
   OchushaBulletinBoard *board;
@@ -739,7 +769,7 @@ ochusha_open_url(OchushaApplication *application, const gchar *url,
 
 #if ENABLE_MAIN_TOOLBAR
 void
-set_current_url(OchushaApplication *application, const gchar *url)
+set_current_url(OchushaApplication *application, const char *url)
 {
   g_return_if_fail(application->url_box != NULL);
 
@@ -747,7 +777,7 @@ set_current_url(OchushaApplication *application, const gchar *url)
 }
 
 
-const gchar *
+const char *
 get_current_url(OchushaApplication *application)
 {
   g_return_val_if_fail(application->url_box != NULL, NULL);
@@ -1038,6 +1068,21 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
       ENTER_MAIN_EVENT_LOOP();
       return;
 
+    case MAIN_MENU_CREATE_NEW_CATEGORY:
+      ochusha_create_new_category(application);
+      ENTER_MAIN_EVENT_LOOP();
+      return;
+
+    case MAIN_MENU_ADD_BOARD:
+      ochusha_add_board(application, NULL);
+      ENTER_MAIN_EVENT_LOOP();
+      return;
+
+    case MAIN_MENU_CREATE_NEW_VIRTUAL_BOARD:
+      ochusha_create_new_virtual_board(application);
+      ENTER_MAIN_EVENT_LOOP();
+      return;
+
     case MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS:
     case MAIN_MENU_HIDE_HIDDEN_THREADS:
     case MAIN_MENU_USE_BUILTIN_CALCULATE_WEIGHT:
@@ -1939,7 +1984,7 @@ preference_dialog_response_cb(GtkWidget *widget, int response_id,
 	tmp_data = g_object_get_data(G_OBJECT(widget), "proxy_url");
 	if (tmp_data != NULL)
 	  {
-	    const gchar *url;
+	    const char *url;
 	    if (application->config.proxy_url != NULL)
 	      G_FREE(application->config.proxy_url);
 	    url = gtk_entry_get_text(GTK_ENTRY(tmp_data));
@@ -2986,7 +3031,7 @@ open_url_dialog_response_cb(GtkWidget *dialog, int response_id,
 
   if (response_id == GTK_RESPONSE_OK)
     {
-      const gchar *url
+      const char *url
 	= gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(open_url_combo)->entry));
       gboolean in_tab = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(open_url_in_tab_button));
       ochusha_open_url(application, url, in_tab, FALSE);
@@ -3011,3 +3056,21 @@ popup_open_url_dialog(OchushaApplication *application)
     initialize_open_url_dialog(application);
   gtk_widget_show_all(open_url_dialog);
 }
+
+
+void
+ochusha_create_new_category(OchushaApplication *application)
+{
+}
+
+
+void
+ochusha_add_board(OchushaApplication *application, const char *url)
+{
+}
+
+
+void
+ochusha_create_new_virtual_board(OchushaApplication *application)
+{
+}
