@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.58 2004/01/11 02:13:14 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.59 2004/01/11 22:35:17 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -302,6 +302,9 @@ typedef enum
   MAIN_MENU_QUIT = 1,
   MAIN_MENU_OPEN_URL,
   MAIN_MENU_REFRESH_BOARDLIST,
+  MAIN_MENU_CREATE_NEW_CATEGORY,
+  MAIN_MENU_ADD_BOARD,
+  MAIN_MENU_CREATE_NEW_VIRTUAL_BOARD,
   MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS,
   MAIN_MENU_REFRESH_THREAD,
   MAIN_MENU_REFRESH_THREAD_ALL,
@@ -324,17 +327,21 @@ void ochusha_set_main_menu_sensitive(OchushaMainMenuAction action,
 void ochusha_clipboard_set_text(OchushaApplication *application,
 				const gchar *text);
 
-void ochusha_open_url(OchushaApplication *application, const gchar *url,
+void ochusha_open_url(OchushaApplication *application, const char *url,
 		      gboolean in_tab, gboolean use_web_browser);
 #if ENABLE_MAIN_TOOLBAR
-void set_current_url(OchushaApplication *application, const gchar *url);
-const gchar *get_current_url(OchushaApplication *application);
+void set_current_url(OchushaApplication *application, const char *url);
+const char *get_current_url(OchushaApplication *application);
 #endif
 
 void setup_for_tab_label_animation(OchushaAsyncBuffer *buffer,
 				   IconLabel *tab_label);
 GtkWidget *get_tab_label(const gchar *label_text);
 
+void ochusha_create_new_category(OchushaApplication *application);
+void ochusha_add_board(OchushaApplication *application, const char *url);
+void ochusha_create_new_virtual_board(OchushaApplication *application);
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
