@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: session.c,v 1.6 2003/12/30 21:53:28 fuyu Exp $
+ * $Id: session.c,v 1.11 2004/01/10 19:35:26 fuyu Exp $
  */
 
 #include "config.h"
@@ -114,9 +114,11 @@ ochusha_session_discard_states(OchushaApplication *application,
       >= PATH_MAX)
     return;
 
+#if 0
   fprintf(application->log_file,
 	  "Removing session directory: %s\n", pathname);
   fflush(application->log_file);
+#endif
 
   ochusha_config_unlink_directory(&application->config, pathname);
 }
@@ -133,15 +135,11 @@ ochusha_session_discard_states(OchushaApplication *application,
     } while (0)
 
 #define OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(gzfile, config, attribute)	\
-  do									\
-    {									\
-      if ((application)->attribute)					\
-	gzprintf(gzfile,						\
-	  "    <attribute name=\"" #attribute	"\">\n"			\
-	  "      <boolean val=\"%s\"/>\n"				\
-	  "    </attribute>\n",						\
-		(application)->attribute ? "true" : "false" );		\
-    } while (0)
+  gzprintf(gzfile,							\
+	   "    <attribute name=\"" #attribute	"\">\n"			\
+	   "      <boolean val=\"%s\"/>\n"				\
+	   "    </attribute>\n",					\
+	   (application)->attribute ? "true" : "false" )
 
 #define OUTPUT_SESSION_ATTRIBUTE_STRING(gzfile, config, attribute)	\
   do									\
@@ -171,6 +169,7 @@ ochusha_session_write_session_xml(OchushaApplication *application,
     {
       fprintf(application->log_file, "Couldn't open session.xml -- <2>.\n");
       fflush(application->log_file);
+      return;
     }
 
   session_xml = gzdopen(fd, "w");
@@ -179,6 +178,7 @@ ochusha_session_write_session_xml(OchushaApplication *application,
       close(fd);
       fprintf(application->log_file, "Couldn't open session.xml -- <3>.\n");
       fflush(application->log_file);
+      return;
     }
 
   gzprintf(session_xml, "<?xml version=\"1.0\"?>\n");
@@ -192,6 +192,24 @@ ochusha_session_write_session_xml(OchushaApplication *application,
   OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application, boardlist_width);
   OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application, threadlist_height);
 
+  OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application,
+			       threadlist_search_direction);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  threadlist_search_enable_wrap);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  threadlist_search_match_case);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  threadlist_search_use_regexp);
+
+  OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application,
+			       thread_search_direction);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  thread_search_enable_wrap);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  thread_search_match_case);
+  OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
+				  thread_search_use_regexp);
+
   gzprintf(session_xml, "  </session>\n");
   gzprintf(session_xml, "</ochusha>\n");
 
@@ -527,6 +545,30 @@ ochusha_session_restore_states(OchushaApplication *application)
 	= ochusha_utils_get_attribute_int(attr, "boardlist_width");
       application->threadlist_height
 	= ochusha_utils_get_attribute_int(attr, "threadlist_height");
+
+      application->threadlist_search_direction
+	= ochusha_utils_get_attribute_int(attr, "threadlist_search_direction");
+      application->threadlist_search_enable_wrap
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "threadlist_search_enable_wrap");
+      application->threadlist_search_match_case
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "threadlist_search_match_case");
+      application->threadlist_search_use_regexp
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "threadlist_search_use_regexp");
+
+      application->thread_search_direction
+	= ochusha_utils_get_attribute_int(attr, "thread_search_direction");
+      application->thread_search_enable_wrap
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "thread_search_enable_wrap");
+      application->thread_search_match_case
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "thread_search_match_case");
+      application->thread_search_use_regexp
+	= ochusha_utils_get_attribute_boolean(attr,
+					      "thread_search_use_regexp");
     }
   else
     fprintf(stderr, "%s is unacceptable as an ochusha's session.xml.\n",
