@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.h,v 1.4 2003/12/30 21:53:29 fuyu Exp $
+ * $Id: threadlist_filter.h,v 1.5 2004/01/07 16:45:39 fuyu Exp $
  */
 
 #ifndef _THREADLIST_FILTER_H_
@@ -79,8 +79,8 @@ typedef struct _RuleModelRelation
 #define THREADLIST_FILTER_RULE_HIDE_ALL				'a'
 
 /* ʲ̾ε§ */
-#define THREADLIST_FILTER_RULE_SHOW_FAVORITE				'F'
-#define THREADLIST_FILTER_RULE_HIDE_NON_FAVORITE			'f'
+#define THREADLIST_FILTER_RULE_SHOW_MARKED				'F'
+#define THREADLIST_FILTER_RULE_HIDE_UNMARKED				'f'
 #define THREADLIST_FILTER_RULE_SHOW_THREAD_SEEN				'S'
 #define THREADLIST_FILTER_RULE_HIDE_THREAD_NEVER_SEEN			's'
 #define THREADLIST_FILTER_RULE_SHOW_THREAD_SEEN_OFFLINE			'O'
@@ -124,8 +124,8 @@ struct _ThreadlistFilterSetting
 
   int number_of_rules_applied;
 
-  RuleModelRelation show_favorite;
-  RuleModelRelation hide_non_favorite;
+  RuleModelRelation show_marked;
+  RuleModelRelation hide_unmarked;
   RuleModelRelation show_seen;
   RuleModelRelation hide_never_seen;
   RuleModelRelation show_seen_offline;
