@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.30 2004/01/10 19:36:38 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.32 2004/01/11 22:33:04 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -127,10 +127,10 @@ typedef enum {
 
 
 typedef enum {
-  THREADLIST_SEARCH_ACTION_BACKWARD,
   THREADLIST_SEARCH_ACTION_FORWARD,
-  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
+  THREADLIST_SEARCH_ACTION_BACKWARD,
   THREADLIST_SEARCH_ACTION_REGEXP_FORWARD,
+  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
   THREADLIST_SEARCH_ACTION_TERMINATE
 } ThreadlistSearchAction;
 
@@ -141,7 +141,8 @@ struct _ThreadlistViewClass
 
   void (*open_thread_view)(ThreadlistView *threadlist_view,
 			   OchushaBBSThread *thread,
-			   gboolean in_tab, gboolean with_browser);
+			   gboolean in_tab, gboolean with_browser,
+			   gboolean fake_relation);
 
   void (*thread_mouse_over)(ThreadlistView *threadlist_view,
 			    OchushaBBSThread *thread);
