@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.c,v 1.9 2003/12/05 15:50:55 fuyu Exp $
+ * $Id: htmlutils.c,v 1.10 2003/12/30 17:22:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -61,7 +61,7 @@ static gchar *encode_unicode_to_utf8(unsigned int character, gchar *buffer);
 static GHashTable *default_entity_dictionary = NULL;
 static GHashTable *reverse_entity_dictionary = NULL;
 
-static gchar *default_entity[] =
+static const gchar * const default_entity[] =
   {
     /* <!ENTITY % HTMLlat1 PUBLIC "-//W3C//ENTITIES// Latin 1//EN//HTML"> */
 
@@ -352,9 +352,9 @@ static gchar *default_entity[] =
 
 
 void
-initialize_default_entity_dictionary()
+initialize_default_entity_dictionary(void)
 {
-  gchar **entry = default_entity;
+  const gchar * const *entry = default_entity;
 
   if (default_entity_dictionary != NULL)
     return;
@@ -366,23 +366,23 @@ initialize_default_entity_dictionary()
   while (*entry != NULL)
     {
       g_hash_table_insert(default_entity_dictionary,
-			  entry[0], entry[1]);
+			  (gpointer)entry[0], (gpointer)entry[1]);
       g_hash_table_insert(reverse_entity_dictionary,
-			  entry[1], entry[0]);
+			  (gpointer)entry[1], (gpointer)entry[0]);
       entry += 2;
     }
 }
 
 
 GHashTable *
-get_default_entity_dictionary()
+get_default_entity_dictionary(void)
 {
   return default_entity_dictionary;
 }
 
 
 GHashTable *
-get_reverse_entity_dictionary()
+get_reverse_entity_dictionary(void)
 {
   return reverse_entity_dictionary;
 }
@@ -969,7 +969,7 @@ fake_anchor_tag(ElementHandler *handler, void *context, const char *head,
   static const char *delimiter = " <>\"\'()\n\t";	/* Τ餤ǡġ */
   const char *cur_pos = head;
   const char *tail;
-  char *attrs[] =
+  const char *attrs[] =
     {
       "href",
       NULL,
