@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.23 2004/01/09 21:16:06 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.24 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -401,8 +401,13 @@ ochusha_bbs_table_check_url(OchushaBBSTable *table, const char *url,
       if (board_p != NULL)
 	{
 	  *board_p = ochusha_bbs_table_lookup_board_by_url(table, board_url);
-	  if (*board_p != NULL && bbs_type_p != NULL)
-	    *bbs_type_p = (*board_p)->bbs_type;
+	  if (bbs_type_p != NULL)
+	    {
+	      if (*board_p != NULL)
+		*bbs_type_p = (*board_p)->bbs_type;
+	      else if (*bbs_type_p == OCHUSHA_BBS_TYPE_2CH)
+		*bbs_type_p = OCHUSHA_BBS_TYPE_2CH_COMPATIBLE;
+	    }
 	}
     }
 
@@ -884,6 +889,7 @@ endElementHandler(void *context, const xmlChar *name)
 		  switch (bbs_type)
 		    {
 		    case OCHUSHA_BBS_TYPE_2CH:
+		    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
 		    case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
 		      board = ochusha_board_2ch_new(board_name, base_url);
 		      break;
