@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.21 2003/12/30 21:53:17 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.25 2004/01/11 03:04:03 fuyu Exp $
  */
 
 #include "config.h"
@@ -124,23 +124,23 @@ ochusha_bbs_thread_class_init(OchushaBBSThreadClass *klass)
   g_object_class_install_property(o_class,
 				  PROP_BOARD,
 				  g_param_spec_object("board",
-						      _("board object"),
-						      _("The board to which this thread belongs"),
+						      _("Board Object"),
+						      _("The Board to Which This Thread Belongs"),
 						      OCHUSHA_TYPE_BULLETIN_BOARD,
 						      G_PARAM_READWRITE));
   g_object_class_install_property(o_class,
 				  PROP_ID,
 				  g_param_spec_string("id",
-						      _("thread id"),
-						      _("String identifies each threads"),
+						      _("Thread ID"),
+						      _("String Identifies Each Threads"),
 						      NULL,
 						      G_PARAM_READWRITE));
   g_object_class_install_property(o_class,
 				  PROP_TITLE,
 				  g_param_spec_string("title",
 						      _("Title"),
-						      _("The title of the thread"),
-						      _("Untitled thread"),
+						      _("The Title of the Thread"),
+						      _("Untitled Thread"),
 						      G_PARAM_READWRITE));
 
   bbs_thread_signals[READ_THREADLIST_ELEMENT_SIGNAL] =
@@ -168,6 +168,13 @@ ochusha_bbs_thread_class_init(OchushaBBSThreadClass *klass)
   klass->write_threadlist_element
     = ochusha_bbs_thread_write_threadlist_element;
 
+  klass->get_board = NULL;
+  klass->get_number_of_responses_on_server = NULL;
+  klass->get_number_of_responses_read = NULL;
+  klass->set_number_of_responses_read = NULL;
+  klass->get_flags = NULL;
+  klass->set_flags = NULL;
+
   klass->get_responses_source = NULL;
   klass->parse_responses = NULL;
   klass->get_last_modified_utc = NULL;
@@ -318,8 +325,13 @@ ochusha_bbs_thread_set_board(OchushaBBSThread *thread,
 OchushaBulletinBoard *
 ochusha_bbs_thread_get_board(OchushaBBSThread *thread)
 {
+  OchushaBBSThreadClass *klass;
   g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
 
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->get_board)
+    return (*klass->get_board)(thread);
+
   return thread->board;
 }
 
@@ -369,9 +381,78 @@ ochusha_bbs_thread_get_title(OchushaBBSThread *thread)
 }
 
 
+int
+ochusha_bbs_thread_get_number_of_responses_on_server(OchushaBBSThread *thread)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), 0);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->get_number_of_responses_on_server)
+    return (*klass->get_number_of_responses_on_server)(thread);
+  return thread->number_of_responses_on_server;
+}
+
+
+int
+ochusha_bbs_thread_get_number_of_responses_read(OchushaBBSThread *thread)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), 0);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->get_number_of_responses_read)
+    return (*klass->get_number_of_responses_read)(thread);
+  return thread->number_of_responses_read;
+}
+
+
+void
+ochusha_bbs_thread_set_number_of_responses_read(OchushaBBSThread *thread,
+						int number)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->set_number_of_responses_read)
+    (*klass->set_number_of_responses_read)(thread, number);
+  else
+    thread->number_of_responses_read = number;
+}
+
+
+int
+ochusha_bbs_thread_get_flags(OchushaBBSThread *thread)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), 0);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->get_flags)
+    return (*klass->get_flags)(thread);
+  return thread->flags;
+}
+
+
+void
+ochusha_bbs_thread_set_flags(OchushaBBSThread *thread, int flags)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  if (klass->set_flags)
+    (*klass->set_flags)(thread, flags);
+  else
+    thread->flags = flags;
+}
+
+
 OchushaAsyncBuffer *
 ochusha_bbs_thread_get_responses_source(OchushaBBSThread *thread,
 					OchushaNetworkBroker *broker,
+					OchushaAsyncBuffer *buffer,
 					OchushaNetworkBrokerCacheMode mode)
 {
   OchushaBBSThreadClass *klass;
@@ -382,25 +463,29 @@ ochusha_bbs_thread_get_responses_source(OchushaBBSThread *thread,
   klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
   g_return_val_if_fail(klass->get_responses_source != NULL, NULL);
 
-  return (*klass->get_responses_source)(thread, broker, mode);
+  return (*klass->get_responses_source)(thread, broker, buffer, mode);
 }
 
 
 const char *
 ochusha_bbs_thread_get_response_character_encoding(OchushaBBSThread *thread)
 {
-  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread)
-		       && OCHUSHA_IS_BULLETIN_BOARD(thread->board), NULL);
-  return ochusha_bulletin_board_get_response_character_encoding(OCHUSHA_BULLETIN_BOARD(thread->board));
+  OchushaBulletinBoard *board;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
+
+  board = ochusha_bbs_thread_get_board(thread);
+  return ochusha_bulletin_board_get_response_character_encoding(OCHUSHA_BULLETIN_BOARD(board));
 }
 
 
 iconv_helper *
 ochusha_bbs_thread_get_response_iconv_helper(OchushaBBSThread *thread)
 {
-  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread)
-		       && OCHUSHA_IS_BULLETIN_BOARD(thread->board), NULL);
-  return ochusha_bulletin_board_get_response_iconv_helper(OCHUSHA_BULLETIN_BOARD(thread->board));
+  OchushaBulletinBoard *board;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
+
+  board = ochusha_bbs_thread_get_board(thread);
+  return ochusha_bulletin_board_get_response_iconv_helper(OCHUSHA_BULLETIN_BOARD(board));
 }
 
 
