@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.18 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.20 2004/01/08 19:44:59 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -95,8 +95,15 @@ struct _OchushaBBSThreadClass
 
 
   /* virtual function table */
+  OchushaBulletinBoard *(*get_board)(OchushaBBSThread *thread);
+  int (*get_number_of_responses_on_server)(OchushaBBSThread *thread);
+  int (*get_number_of_responses_read)(OchushaBBSThread *thread);
+  void (*set_number_of_responses_read)(OchushaBBSThread *thread, int number);
+  int (*get_flags)(OchushaBBSThread *thread);
+  void (*set_flags)(OchushaBBSThread *thread, int flags);
   OchushaAsyncBuffer *(*get_responses_source)(OchushaBBSThread *thread,
 					OchushaNetworkBroker *broker,
+					OchushaAsyncBuffer *buffer,
 					OchushaNetworkBrokerCacheMode mode);
   gboolean (*parse_responses)(OchushaBBSThread *thread,
 			      OchushaAsyncBuffer *buffer,
@@ -153,6 +160,10 @@ const gchar *ochusha_bbs_thread_get_title(OchushaBBSThread *thread);
 
 int ochusha_bbs_thread_get_number_of_responses_on_server(OchushaBBSThread *thread);
 int ochusha_bbs_thread_get_number_of_responses_read(OchushaBBSThread *thread);
+void ochusha_bbs_thread_set_number_of_responses_read(OchushaBBSThread *thread,
+						     int number);
+int ochusha_bbs_thread_get_flags(OchushaBBSThread *thread);
+void ochusha_bbs_thread_set_flags(OchushaBBSThread *thread, int flags);
 
 time_t ochusha_bbs_thread_get_last_modified_utc(OchushaBBSThread *thread);
 
@@ -172,6 +183,7 @@ gboolean ochusha_bbs_thread_check_url(OchushaBBSThread *thread,
 OchushaAsyncBuffer *ochusha_bbs_thread_get_responses_source(
 					OchushaBBSThread *thread,
 					OchushaNetworkBroker *broker,
+					OchushaAsyncBuffer *buffer,
 					OchushaNetworkBrokerCacheMode mode);
 const char *ochusha_bbs_thread_get_response_character_encoding(
 						OchushaBBSThread *thread);
