@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.30 2004/01/08 19:44:59 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.31 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,6 +52,9 @@
 #include <zlib.h>
 
 
+#define ANALYSIS_INTERVAL	50
+
+
 static OchushaBulletinBoardClass *parent_class = NULL;
 
 
@@ -272,6 +275,7 @@ ochusha_board_2ch_get_subject_txt_encoding(OchushaBulletinBoard *board)
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       return "CP932";
 
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
@@ -414,6 +418,7 @@ ochusha_board_2ch_generate_board_id(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
       {
 	char *tmp_pos = strchr(abs_path + 1, '/');
@@ -562,6 +567,7 @@ ochusha_board_2ch_get_response_character_encoding(OchushaBulletinBoard *board)
   switch (((OchushaBulletinBoard *)board)->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       return "CP932";
 
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
@@ -581,6 +587,7 @@ ochusha_board_2ch_get_response_iconv_helper(OchushaBulletinBoard *board)
   switch (((OchushaBulletinBoard *)board)->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       return cp932_to_utf8_helper;
 
     default:
@@ -597,6 +604,7 @@ ochusha_board_2ch_is_new_thread_supported(OchushaBulletinBoard *board)
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       return TRUE;
 
     default:
@@ -635,6 +643,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       break;
 
     default:
@@ -696,6 +705,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&time=%ld", title, from, mail, message, bbs, time);
       break;
 
@@ -793,6 +803,7 @@ ochusha_board_2ch_get_read_cgi_url(OchushaBoard2ch *board_2ch)
       switch (board->bbs_type)
 	{
 	case OCHUSHA_BBS_TYPE_2CH:
+	case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
 	case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
 	  if (snprintf(url, PATH_MAX, "http://%s/test/read.cgi",
 		       ochusha_bulletin_board_get_server(board)) < PATH_MAX)
@@ -913,6 +924,15 @@ undo_thread_ref(gpointer data, gpointer user_data)
 }
 
 
+static gboolean
+advance_parsing(gpointer data)
+{
+  ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
+  OCHU_OBJECT_UNREF((GObject *)data);
+  return FALSE;
+}
+
+
 /*
  * refresh_threadlist_by_subject_txt:
  *
@@ -932,7 +952,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 {
   char default_buffer[PATH_MAX];
   char scan_buffer[5];
-  gboolean result;
+  gboolean result = FALSE;
   GSList *thread_list = NULL;
   GSList *old_thread_list = board->thread_list;
   iconv_t converter;
@@ -950,6 +970,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       converter_helper = cp932_to_utf8_helper;
       break;
 
@@ -971,15 +992,18 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
   ochusha_async_buffer_lock(buffer);
   {
     unsigned int offset = 0;
+    gboolean buffer_fixed = FALSE;
 
     while (TRUE)
       {
 	char *buffer_top = (char *)buffer->buffer;
 	char *cur_pos = buffer_top + offset;
 	unsigned int rest_of_data = buffer->length - offset;
-	char *eol_pos;
+	char *eol_pos = NULL;
+	int interval = ANALYSIS_INTERVAL;
 
 	while (rest_of_data > 0
+	       && interval-- > 0
 	       && (eol_pos = memchr(cur_pos, '\n', rest_of_data)) != NULL)
 	  {
 	    char *thread_id;
@@ -1067,7 +1091,6 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		if (each_thread_cb != NULL
 		    && !(*each_thread_cb)(thread, callback_data))
 		  {
-		    result = FALSE;
 		    break;
 		  }
 	      }
@@ -1077,30 +1100,64 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	    buffer_top = (char *)buffer->buffer;
 	    cur_pos = buffer_top + offset;
 	    rest_of_data = buffer->length - offset;
+	    eol_pos = NULL;
 	  }
 
-	if (buffer->fixed)
+	if (!buffer_fixed && buffer->fixed)
+	  {
+	    buffer_fixed = TRUE;
+	    eol_pos = NULL;
+	    continue;
+	  }
+
+	if (buffer->fixed && eol_pos == NULL && interval > 0)
 	  {
 	    result = TRUE;
-	    break;
+	    goto terminated;
 	  }
 
-	if (!ochusha_async_buffer_wait(buffer))
+	if (interval > 0)
 	  {
+	    if (!ochusha_async_buffer_wait(buffer))
+	      {
 #if DEBUG_ASYNC_BUFFER_MOST
-	    fprintf(stderr, "buffer has been terminated.\n");
+		fprintf(stderr, "buffer has been terminated.\n");
 #endif
-	    result = FALSE;
-	    break;
+		goto terminated;
+	      }
 	  }
+	else
+	  {
+	    if (ochusha_async_buffer_is_busy(buffer))
+	      {
+		/*
+		 * buffer˥륹åɤsuspend/terminate
+		 * ȿ뤿˥å
+		 */
+		if (!ochusha_async_buffer_wait(buffer))
+		  goto terminated;
+	      }
+	    else
+	      {
+		/*
+		 * GUIΥ쥹ݥ󥹤βܻؤ¸
+		 */
+		OCHU_OBJECT_REF(G_OBJECT(buffer));
+		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
+				advance_parsing, buffer, NULL);
+		if (!ochusha_async_buffer_wait(buffer))
+		  goto terminated;
+	      }
+	  }
+	interval = ANALYSIS_INTERVAL;
 
 	if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
-	    result = FALSE;
-	    break;
+	    goto terminated;
 	  }
       }
   }
+ terminated:
   ochusha_async_buffer_unlock(buffer);
 
   if (result)
