@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.h,v 1.3 2003/06/20 18:10:06 fuyu Exp $
+ * $Id: ochusha_board_category.h,v 1.4 2003/12/24 03:40:50 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BOARD_CATEGORY_H_
@@ -32,6 +32,7 @@
 #include <glib-object.h>
 #include <glib.h>
 
+#include <zlib.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -71,7 +72,7 @@ struct _OchushaBoardCategoryClass
   void (*read_boardlist_element)(OchushaBoardCategory *category,
 				 GHashTable *board_attributes);
   void (*write_boardlist_element)(OchushaBoardCategory *category,
-				  FILE *boardlist_xml);
+				  gzFile *boardlist_xml);
 };
 
 
