@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.27 2004/01/11 03:04:03 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.28 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -357,6 +357,7 @@ ochusha_bulletin_board_set_name(OchushaBulletinBoard *board,
     g_free(board->name);
 
   board->name = wipe_string(name);
+  g_object_notify(G_OBJECT(board), "name");
 }
 
 
@@ -406,6 +407,7 @@ ochusha_bulletin_board_set_base_url(OchushaBulletinBoard *board,
     G_FREE(board->id);
 
   board->id = (*klass->generate_board_id)(board, url);
+  g_object_notify(G_OBJECT(board), "base_url");
 }
 
 
@@ -448,6 +450,15 @@ ochusha_bulletin_board_set_bbs_type(OchushaBulletinBoard *board,
 }
 
 
+int
+ochusha_bulletin_board_get_bbs_type(OchushaBulletinBoard *board)
+{
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board),
+		       OCHUSHA_BBS_TYPE_UNKNOWN);
+  return board->bbs_type;
+}
+
+
 static char *
 ochusha_bulletin_board_generate_board_id(OchushaBulletinBoard *board,
 					 const char *url)
