@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.17 2004/01/09 17:01:50 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.18 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -63,7 +63,8 @@ enum
   OCHUSHA_BBS_TYPE_JBBS,
   OCHUSHA_BBS_TYPE_MACHIBBS,
   OCHUSHA_BBS_TYPE_JBBS_SHITARABA,
-  OCHUSHA_BBS_TYPE_MITINOKU
+  OCHUSHA_BBS_TYPE_MITINOKU,
+  OCHUSHA_BBS_TYPE_2CH_COMPATIBLE,
 };
 
 
@@ -171,6 +172,7 @@ const char *ochusha_bulletin_board_get_id(OchushaBulletinBoard *board);
 
 void ochusha_bulletin_board_set_bbs_type(OchushaBulletinBoard *board,
 					 int bbs_type);
+int ochusha_bulletin_board_get_bbs_type(OchushaBulletinBoard *board);
 
 OchushaBBSThread *ochusha_bulletin_board_bbs_thread_new(
 					OchushaBulletinBoard *board,
