@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.23 2003/12/26 16:15:29 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.24 2003/12/30 17:22:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -936,7 +936,7 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 {
   int fd;
   gzFile *config_xml;
-  char *empty_string = "";
+  const char *empty_string = "";
 
   fd = ochusha_config_open_file(config, OCHUSHA_CONFIG_XML, subdir,
 				O_WRONLY | O_TRUNC | O_CREAT);
@@ -968,7 +968,7 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 				  enable_proxy_only_for_posting);
 
   if (config->proxy_url == NULL)
-    config->proxy_url = empty_string;
+    config->proxy_url = (char *)empty_string;
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, proxy_url);
   if (config->proxy_url == empty_string)
     config->proxy_url = NULL;
@@ -976,16 +976,16 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, enable_proxy_auth);
 
   if (config->proxy_user == NULL)
-    config->proxy_user = empty_string;
+    config->proxy_user = (char *)empty_string;
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, proxy_user);
   if (config->proxy_user == empty_string)
     config->proxy_user = NULL;
 
   if (config->proxy_password == NULL)
-    config->proxy_password = empty_string;
+    config->proxy_password = (char *)empty_string;
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, proxy_password);
   if (config->proxy_password == empty_string)
-    config->proxy_password = empty_string;
+    config->proxy_password = NULL;
 
   if (optional != NULL)
     (*optional)(config_xml, user_data);
