@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.52 2004/01/08 19:44:59 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.53 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -1111,6 +1111,8 @@ ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread, int from,
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
+    case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
       {
 	if (from >= to)
 	  snprintf(url, PATH_MAX, "../test/read.cgi/%s/%s/%d",
