@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.33 2004/01/09 16:47:55 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.34 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -417,7 +417,7 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
 		{
 		  char tmp_char = tmp_pos[1];
 		  tmp_pos[1] = '\0';
-		  if (snprintf(board_url, PATH_MAX, "http://%s/%s/", server,
+		  if (snprintf(board_url, PATH_MAX, "http://%s/%s", server,
 			       path_pos) < PATH_MAX)
 		    board_id = G_STRDUP(board_id_head);
 		  else
@@ -1015,6 +1015,8 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       result = snprintf(url, PATH_MAX, "http://%s/test/bbs.cgi",
 			ochusha_bulletin_board_get_server(board));
       break;
