@@ -23,10 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: worker.c,v 1.1.1.1 2003/05/10 16:34:28 fuyu Exp $
+ * $Id: worker.c,v 1.2 2003/06/06 19:38:05 fuyu Exp $
  */
 
+#include "config.h"
+
+#include "ochusha_private.h"
 #include "ochusha.h"
+
 #include "worker.h"
 
 #include <glib.h>
@@ -171,6 +175,8 @@ terminate_workers(void)
 	  fprintf(stderr, "Couldn't join a thread\n");
 	  abort();
 	}
+
+      G_FREE(thread);
     }
 }
 
@@ -178,7 +184,7 @@ terminate_workers(void)
 static WorkerThread *
 worker_thread_new(void)
 {
-  WorkerThread *thread = (WorkerThread *)calloc(1, sizeof(WorkerThread));
+  WorkerThread *thread = G_NEW0(WorkerThread, 1);
   thread->command = GO_AHEAD;
 
   if (pthread_create(&thread->id, &worker_thread_attribute,
@@ -287,7 +293,7 @@ worker_thread_main(void *args)
 	  JOB_LIST_UNLOCK;
 
 	  (*job->job)(self, job->args);
-	  free(job);
+	  G_FREE(job);
 	  JOB_LIST_LOCK;
 	}
     }
