@@ -32,14 +32,16 @@
 #endif
 
 /* config */
+/* spec. config */
 #define USE_NAMED_GROUP
 #define USE_SUBEXP_CALL
-#define USE_OP_PUSH_OR_JUMP_EXACT
-#define USE_QUALIFIER_PEEK_NEXT
-#define USE_RECYCLE_NODE
+#define USE_FOLD_MATCH                                /* ess-tsett etc... */ 
 #define USE_NEWLINE_AT_END_OF_STRING_HAS_EMPTY_LINE   /* /\n$/ =~ "\n" */
 #define USE_WARNING_REDUNDANT_NESTED_REPEAT_OPERATOR
-/* #define USE_SBMB_CLASS */
+/* internal config */
+#define USE_RECYCLE_NODE
+#define USE_OP_PUSH_OR_JUMP_EXACT
+#define USE_QUALIFIER_PEEK_NEXT
 
 #define INIT_MATCH_STACK_SIZE                     160
 #define MATCH_STACK_LIMIT_SIZE                 200000
@@ -50,10 +52,10 @@
 #define USE_VARIABLE_META_CHARS
 #define USE_VARIABLE_SYNTAX
 #define USE_WORD_BEGIN_END          /* "\<": word-begin, "\>": word-end */
-#define DEFAULT_TRANSTABLE_EXIST    1
-#define THREAD_ATOMIC_START   /* depend on thread system */
-#define THREAD_ATOMIC_END     /* depend on thread system */
-#define THREAD_PASS           /* depend on thread system */
+#define USE_POSIX_REGION_OPTION     /* needed for POSIX API support */
+#define THREAD_ATOMIC_START         /* depend on thread system */
+#define THREAD_ATOMIC_END           /* depend on thread system */
+#define THREAD_PASS                 /* depend on thread system */
 #define xmalloc     malloc
 #define xrealloc    realloc
 #define xfree       free
@@ -117,6 +119,8 @@
 # include "regex.h"
 #endif
 
+#include "regenc.h"
+
 #ifdef MIN
 #undef MIN
 #endif
@@ -258,46 +262,13 @@ typedef unsigned int  BitStatusType;
 
 #define INT_MAX_LIMIT           ((1UL << (SIZEOF_INT * 8 - 1)) - 1)
 
-typedef unsigned int   WCINT;
-
-#define SIZE_WCINT        sizeof(WCINT)
-#define GET_WCINT(wc,p)   (wc) = *((WCINT* )(p))
-
 #define INFINITE_DISTANCE  ~((RegDistance )0)
 
-#if defined STDC_HEADERS || (!defined isascii && !defined HAVE_ISASCII)
-# define IS_ASCII(c) 1
-#else
-# define IS_ASCII(c) isascii(c)
-#endif
-
-#ifdef isblank
-# define IS_BLANK(c) (IS_ASCII(c) && isblank(c))
-#else
-# define IS_BLANK(c) ((c) == ' ' || (c) == '\t')
-#endif
-#ifdef isgraph
-# define IS_GRAPH(c) (IS_ASCII(c) && isgraph(c))
-#else
-# define IS_GRAPH(c) (IS_ASCII(c) && isprint(c) && !isspace(c))
-#endif
-
-#define IS_PRINT(c)  (isprint(c)  && IS_ASCII(c))
-#define IS_ALNUM(c)  (isalnum(c)  && IS_ASCII(c))
-#define IS_ALPHA(c)  (isalpha(c)  && IS_ASCII(c))
-#define IS_LOWER(c)  (islower(c)  && IS_ASCII(c))
-#define IS_UPPER(c)  (isupper(c)  && IS_ASCII(c))
-#define IS_CNTRL(c)  (iscntrl(c)  && IS_ASCII(c))
-#define IS_PUNCT(c)  (ispunct(c)  && IS_ASCII(c))
-#define IS_SPACE(c)  (isspace(c)  && IS_ASCII(c))
-#define IS_DIGIT(c)  (isdigit(c)  && IS_ASCII(c))
-#define IS_XDIGIT(c) (isxdigit(c) && IS_ASCII(c))
-#define IS_ODIGIT(c) (IS_DIGIT(c) && (c) < '8')
-
-#define DIGITVAL(c)    ((c) - '0')
-#define ODIGITVAL(c)   DIGITVAL(c)
-#define XDIGITVAL(c) \
-  (IS_DIGIT(c) ? DIGITVAL(c) : (IS_UPPER(c) ? (c) - 'A' + 10 : (c) - 'a' + 10))
+#define DIGITVAL(code)    ((code) - '0')
+#define ODIGITVAL(code)   DIGITVAL(code)
+#define XDIGITVAL(enc,code) \
+  (ENC_IS_CODE_DIGIT(enc,code) ? DIGITVAL(code) \
+       : (ENC_IS_CODE_UPPER(enc,code) ? (code) - 'A' + 10 : (code) - 'a' + 10))
 
 #define IS_SINGLELINE(option)     ((option) & REG_OPTION_SINGLELINE)
 #define IS_MULTILINE(option)      ((option) & REG_OPTION_MULTILINE)
@@ -441,114 +412,6 @@ typedef struct _BBuf {
 
 #define BBUF_GET_BYTE(buf, pos) (buf)->p[(pos)]
 
-extern UChar* DefaultTransTable;
-#define TOLOWER(enc,c)           (DefaultTransTable[c])
-
-/* methods for support multi-byte code, */
-#define ismb(code,c)             (mblen((code),(c)) != 1)
-#define MB2WC(p,end,code)        mb2wc((p),(end),(code))
-#define MBBACK(code,start,s,n)   step_backward_char((code),(start),(s),(n))
-
-#ifdef REG_RUBY_M17N
-
-#define MB2WC_AVAILABLE(enc)     1
-#define WC2MB_FIRST(enc, wc)          m17n_firstbyte((enc),(wc))
-#define WC2MBLEN(enc, wc)             m17n_codelen((enc),(wc))
-
-#define mbmaxlen(enc)                 m17n_mbmaxlen(enc)
-#define mblen(enc,c)                  m17n_mbclen(enc,c)
-#define mbmaxlen_dist(enc) \
-      (mbmaxlen(enc) > 0 ? mbmaxlen(enc) : INFINITE_DISTANCE)
-
-#define IS_SINGLEBYTE_CODE(enc)    (m17n_mbmaxlen(enc) == 1)
-/* #define IS_INDEPENDENT_TRAIL(enc)  m17n_independent_trail(enc) */
-#define IS_INDEPENDENT_TRAIL(enc)  IS_SINGLEBYTE_CODE(enc)
-
-#define IS_CODE_ASCII(enc,c)     IS_ASCII(c)
-#define IS_CODE_GRAPH(enc,c)     IS_GRAPH(c)
-#define IS_CODE_PRINT(enc,c)     m17n_isprint(enc,c)
-#define IS_CODE_ALNUM(enc,c)     m17n_isalnum(enc,c)
-#define IS_CODE_ALPHA(enc,c)     m17n_isalpha(enc,c)
-#define IS_CODE_LOWER(enc,c)     m17n_islower(enc,c)
-#define IS_CODE_UPPER(enc,c)     m17n_isupper(enc,c)
-#define IS_CODE_CNTRL(enc,c)     m17n_iscntrl(enc,c)
-#define IS_CODE_PUNCT(enc,c)     m17n_ispunct(enc,c)
-#define IS_CODE_SPACE(enc,c)     m17n_isspace(enc,c)
-#define IS_CODE_BLANK(enc,c)     IS_BLANK(c)
-#define IS_CODE_DIGIT(enc,c)     m17n_isdigit(enc,c)
-#define IS_CODE_XDIGIT(enc,c)    m17n_isxdigit(enc,c)
-
-#define IS_CODE_WORD(enc,c)      m17n_iswchar(enc,c)
-#define ISNOT_CODE_WORD(enc,c)  (!m17n_iswchar(enc,c))
-
-#define IS_WORD_STR(code,s,end) \
-  (ismb((code),*(s)) ? (s + mblen((code),*(s)) <= (end)) : \
-                       m17n_iswchar(code,*(s)))
-#define IS_WORD_STR_INC(code,s,end) \
-  (ismb((code),*(s)) ? ((s) += mblen((code),*(s)), (s) <= (end)) : \
-                       (s++, m17n_iswchar(code,s[-1])))
-
-#define IS_WORD_HEAD(enc,c) (ismb(enc,c) ? 1 : IS_CODE_WORD(enc,c))
-
-#define IS_SB_WORD(code,c)  (mblen(code,c) == 1 && IS_CODE_WORD(code,c))
-#define IS_MB_WORD(code,c)  ismb(code,c)
-
-#define mb2wc(p,e,enc)        m17n_codepoint((enc),(p),(e))
-
-#else  /* REG_RUBY_M17N */
-
-#define mb2wc(p,e,code)              regex_mb2wc((p),(e),(code))
-
-#define MB2WC_AVAILABLE(code)       1
-#define WC2MB_FIRST(code, wc)       regex_wc2mb_first(code, wc)
-#define WC2MBLEN(code, wc)          regex_wc2mblen(code,wc)
-
-#define mbmaxlen_dist(code)         mbmaxlen(code)
-#define mbmaxlen(code)              regex_mb_max_length(code)
-#define mblen(code,c)               (code)[(int )(c)]
-
-#define IS_SINGLEBYTE_CODE(code)    ((code) == REGCODE_ASCII)
-#define IS_INDEPENDENT_TRAIL(code) \
-        ((code) == REGCODE_ASCII || (code) == REGCODE_UTF8)
-
-#define IS_CODE_ASCII(code,c)        IS_ASCII(c)
-#define IS_CODE_GRAPH(code,c)        IS_GRAPH(c)
-#define IS_CODE_PRINT(code,c)        IS_PRINT(c)
-#define IS_CODE_ALNUM(code,c)        IS_ALNUM(c)
-#define IS_CODE_ALPHA(code,c)        IS_ALPHA(c)
-#define IS_CODE_LOWER(code,c)        IS_LOWER(c)
-#define IS_CODE_UPPER(code,c)        IS_UPPER(c)
-#define IS_CODE_CNTRL(code,c)        IS_CNTRL(c)
-#define IS_CODE_PUNCT(code,c)        IS_PUNCT(c)
-#define IS_CODE_SPACE(code,c)        IS_SPACE(c)
-#define IS_CODE_BLANK(code,c)        IS_BLANK(c)
-#define IS_CODE_DIGIT(code,c)        IS_DIGIT(c)
-#define IS_CODE_ODIGIT(code,c)       IS_ODIGIT(c)
-#define IS_CODE_XDIGIT(code,c)       IS_XDIGIT(c)
-
-#define IS_SB_WORD(code,c)  (IS_CODE_ALNUM(code,c) || (c) == '_')
-#define IS_MB_WORD(code,c)  ismb(code,c)
-
-#define IS_CODE_WORD(code,c) \
-  (IS_SB_WORD(code,c) && ((c) < 0x80 || (code) == REGCODE_ASCII))
-#define ISNOT_CODE_WORD(code,c) \
-  ((!IS_SB_WORD(code,c)) && !ismb(code,c))
-
-#define IS_WORD_STR(code,s,end) \
-  (ismb((code),*(s)) ? (s + mblen((code),*(s)) <= (end)) : \
-                       IS_SB_WORD(code,*(s)))
-#define IS_WORD_STR_INC(code,s,end) \
-  (ismb((code),*(s)) ? ((s) += mblen((code),*(s)), (s) <= (end)) : \
-                       (s++, IS_SB_WORD(code,s[-1])))
-
-#define IS_WORD_HEAD(code,c) (ismb(code,c) ? 1 : IS_SB_WORD(code,c))
-
-extern int   regex_mb_max_length P_((RegCharEncoding code));
-extern WCINT regex_mb2wc P_((UChar* p, UChar* end, RegCharEncoding code));
-extern int   regex_wc2mb_first P_((RegCharEncoding code, WCINT wc));
-extern int   regex_wc2mblen P_((RegCharEncoding code, WCINT wc));
-#endif /* not REG_RUBY_M17N */
-
 
 #define ANCHOR_BEGIN_BUF        (1<<0)
 #define ANCHOR_BEGIN_LINE       (1<<1)
@@ -779,12 +642,12 @@ typedef int         RepeatNumType;
 
 
 typedef struct {
-  WCINT esc;
-  WCINT anychar;
-  WCINT anytime;
-  WCINT zero_or_one_time;
-  WCINT one_or_more_time;
-  WCINT anychar_anytime;
+  CodePoint esc;
+  CodePoint anychar;
+  CodePoint anytime;
+  CodePoint zero_or_one_time;
+  CodePoint one_or_more_time;
+  CodePoint anychar_anytime;
 } RegMetaCharTableType;
 
 extern RegMetaCharTableType RegMetaCharTable;
@@ -819,9 +682,9 @@ extern char* regex_error_code_to_format P_((int code));
 extern void  regex_snprintf_with_pattern PV_((char buf[], int bufsize, RegCharEncoding enc, char* pat, char* pat_end, char *fmt, ...));
 extern UChar* regex_strdup P_((UChar* s, UChar* end));
 extern int  regex_bbuf_init P_((BBuf* buf, int size));
-extern int  regex_alloc_init P_((regex_t** reg, RegOptionType option, RegCharEncoding code, RegSyntaxType* syntax));
+extern int  regex_alloc_init P_((regex_t** reg, RegOptionType option, RegCharEncoding enc, RegSyntaxType* syntax));
 extern int  regex_compile P_((regex_t* reg, UChar* pattern, UChar* pattern_end, RegErrorInfo* einfo));
 extern void regex_chain_reduce P_((regex_t* reg));
-extern int  regex_is_in_wc_range P_((UChar* p, WCINT wc));
+extern int  regex_is_in_code_range P_((UChar* p, CodePoint code));
 
 #endif /* REGINT_H */
